hype.core

Hypermedia functions for ring routers.

hype currently provides support for:

  • generating paths or URLs,
  • including template parameters, and
  • converting between paths and URLs.

hype includes built in backends for bidi and reitit and includes extension points allowing other routers to be supported.

Hypermedia functions for `ring` routers.

`hype` currently provides support for:

  - generating paths or URLs,
  - including template parameters, and
  - converting between paths and URLs.

`hype` includes built in backends for `bidi` and `reitit` and includes
extension points allowing other routers to be supported.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries